projectal.entities.customer API documentation

# projectal.entities.customer

View Source

     1from projectal.entity import Entity
     2from projectal.linkers import *
     3
     4
     5class Customer(
     6    Entity,
     7    LocationLinker,
     8    ContactLinker,
     9    FileLinker,
    10    ProjectLinker,
    11    NoteLinker,
    12    TagLinker,
    13):
    14    """
    15    Implementation of the [Customer](https://projectal.com/docs/latest/#tag/Customer) API.
    16    """
    17
    18    _path = "customer"
    19    _name = "customer"
    20    _links = [LocationLinker, ContactLinker, FileLinker, NoteLinker, TagLinker]
    21    _links_reverse = [ProjectLinker]

class Customer(projectal.entity.Entity, projectal.linkers.LocationLinker, projectal.linkers.ContactLinker, projectal.linkers.FileLinker, projectal.linkers.ProjectLinker, projectal.linkers.NoteLinker, projectal.linkers.TagLinker): View Source

     6class Customer(
     7    Entity,
     8    LocationLinker,
     9    ContactLinker,
    10    FileLinker,
    11    ProjectLinker,
    12    NoteLinker,
    13    TagLinker,
    14):
    15    """
    16    Implementation of the [Customer](https://projectal.com/docs/latest/#tag/Customer) API.
    17    """
    18
    19    _path = "customer"
    20    _name = "customer"
    21    _links = [LocationLinker, ContactLinker, FileLinker, NoteLinker, TagLinker]
    22    _links_reverse = [ProjectLinker]

Implementation of the Customer API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.LocationLinker
  link_location
  unlink_location
projectal.linkers.ContactLinker
  link_contact
  unlink_contact
projectal.linkers.FileLinker
  link_file
  unlink_file
projectal.linkers.ProjectLinker
  link_project
  unlink_project
projectal.linkers.TagLinker
  link_tag
  unlink_tag
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy